import random

from .puns.languages import all_languages


class LanguageNotFoundError(Exception):
    pass

class CategoryNotFoundError(Exception):
    pass



# Gets all puns of a category.
def get_all_puns(language='en', category='all', puns_file='default'):
    """
    PARAMETERS
    __________
    language: str
        possibilities: 'en', 'it'
    category: str
        possibilities: 'all', 'blackhumor', 'thonguetwist', 'puns'
    puns_file: str
        possibilities: 'default'
    ----------------------------
    OUTPUT
    ______
    puns: list
    """

    if language not in all_languages:
        raise LanguageNotFoundError(f'Currently the {language} language is not supported. Submit your puns for this new language on github!')

    puns = all_languages[language]

    if category not in puns:
        raise CategoryNotFoundError(f'Currently the {category} category is not supported. Submit new categories for the {language} language on github!')

    return puns[category]
    


# Random selection of a pun from all puns of a category.
def get_pun(language='en', category='all', puns_file='default'):
    """
    PARAMETERS
    __________
    language: str
        possibilities: 'en', 'it'
    category: str
        possibilities: 'all', 'blackhumor', 'thonguetwist', 'puns'
    puns_file: str
        possibilities: 'default'
    ----------------------------
    OUTPUT
    ______
    pun: str
    """

    pun = get_all_puns(language, category, puns_file)
    
    return random.choice(pun)




blackhumor = [
    
]

tongue_twister = [
    
]

puns = [
    
]

# ------------------------------------------------------------------------------

# Chanhe this to the language code
language_puns = {
    'blackhumor': blackhumor,
    'tongue_twister': tongue_twister,
    'puns': puns,
    'all': blackhumor + tongue_twister + puns
}




blackhumor = [
    "Dove sono seduti gli ebrei in una macchina? Nel posacenere",
    "Sara sta andando sull'altalena, ma ad un certo punto cade. Perchè? Perchè non ha le braccia. Toc toc. Chi è? Di sicuro non Sara.",
    "Una ragazza va all'interrogazione sui diritti delle donne, ma fa scena muta. Prende 10.",
    "Ad una bambina in Africa sono arrivate le medicine contro l'ebola, ma dietro c'è scritto \"da consumare dopo i pasti\"",
    "Qual è la differenza tra un depresso e la pizza? Che la pizza non si taglia da sola",
    "Perchè in una partita a scacchi New York perde? Perchè le mancano le due torri",
    "Sai cos'hanno di speciale le barzellette sui bambini morti? Che non diventano mai vecchie",
    "Qual è la parte più bianca di un africano? Il padrone"
]

tongue_twister = [
    "Trentatrè trentini entrarono a Treno tutti e trentatrè trotterellando",
    "Tre tigri contro tre tigri",
    "Se l'arcivescovo di Costantinopoli si disarcivescoviscostantinopolizzasse, tu ti disarcivescoviscostantinopolizzeresti come si è disarcivescoviscostantinopolizzato l'arcivescovo di Costantinopoli?"
]

puns = [
    "Cesare il popolo chiede sesterzi! Nono vado dritto",
    "Chi può intendere intenda, gli altri in camper",
    "Piacere, Gofredo. Anche a mi ma resisto",
    "Due ciechi si incontrano per strada e se le suonano di santa ragione. Non si potevano vedere",
    "Come fai a far parlare uno spago? Basta dargli corda",
    "Un elicottero cade in un cimitero. I carabinieri hanno già recuperato 300 corpi"
]

# ------------------------------------------------------------------------------

it_puns = {
    'blackhumor': blackhumor,
    'tongue_twister': tongue_twister,
    'puns': puns,
    'all': blackhumor + tongue_twister + puns
}




blackhumor = [
    "Give a man a match, and he'll be warm for a few hours. Set a man on fire, and he will be warm for the rest of his life",
    "My wife and I have reached the difficult decision that we do not want children. If anybody does, please just send me your contact details and we can drop them off tomorrow",
    "I have a fish that can breakdance! Only for 20 seconds though, and only once",
    "Give a man a plane ticket and he flies for the day. Push him out of the plane at 3,000 feet and he'll fly for the rest of his life",
    "I was in Russia listening to a stand-up comedian making fun of Putin. The jokes weren't that good, but I liked the execution",
    "Why can't orphans play baseball? They don't know where home is",
    "I started crying when dad was cutting onions. Onions was such a good dog"
]

tongue_twister = [
    "I scream, you scream, we all scream for ice cream",
    "I saw Susie sitting in a shoeshine shop",
    "Can you can a can as a canner can can a can?"
]

puns = [
    "Why did Adele cross the road? To say hello from the other side",
    "What kind of concert only costs 45 cents? A 50 Cent concert featuring Nickelback",
    "What do you call a fake noodle? An impasta",
    "To the guy who invented zero, thanks for nothing",
    "So what if I don’t know what apocalypse means? It’s not the end of the world!",
    "I've got a lot of unemployement jokes, but none of them would work",
    "How di you call a Mexican who lost his car? Carloss",
    "What's the difference between a fish and a guitar? You can't tuna fish"
]

# ------------------------------------------------------------------------------

en_puns = {
    'blackhumor': blackhumor,
    'tongue_twister': tongue_twister,
    'puns': puns,
    'all': blackhumor + tongue_twister + puns
}



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, 'README.md'), encoding='utf-8') as fh:
    long_description = '\n' + fh.read()

VERSION = '0.2.2.0'
DESCRIPTION = 'Simple random puns picker'

# Setting up
setup(
    name='pypuns',
    version=VERSION,
    url='https://github.com/PyPuns/PyPuns',
    author='Bunz',
    author_email='66bunz@gmail.com',
    
    description=DESCRIPTION,
    long_description_content_type='text/markdown',
    long_description=long_description,

    packages=['pypuns', 'pypuns.puns'],
    include_package_data=True,
    
    install_requires=[],

    keywords=['python', 'puns', 'pypuns', 'chatbots', 'chat', 'jokes', 'random jokes', 'random joke', 'joke', 'pun', 'random pun', 'random puns'],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Natural Language :: English',
        'Topic :: Software Development :: Build Tools',
        'Operating System :: OS Independent',
    ],

    project_urls={
        'Bug Reports': 'https://github.com/PyPuns/PyPuns/issues',
        'Funding': 'https://www.buymeacoffee.com/66bunz',
        'Say Thanks!': 'https://saythanks.io/to/66Bunz',
        'Source': 'https://github.com/PyPuns/PyPuns',
    },
)
